@@ -35,6 +35,7 @@ class Base(Controller):
         self.app.args.print_help()
 
     @ex(
+        # TODO: implement `--home` for setting up home address 
         help='AWS Security Groups helper functions',
         arguments=[
             (['action'],{
@@ -223,7 +224,6 @@ class Base(Controller):
         ]
     )
     def ssh(self):
-        #TODO: missing servers
         from ..ext.sshconf import read_ssh_config
         if self.app.pargs.action=='set':
             ssh_config_obj = read_ssh_config('/Users/jakub/.ssh/config')
@@ -276,9 +276,10 @@ class Base(Controller):
         # resets the config
         # TODO this config method needs programmatic acces for spot instances
         if args.action=='set':
+            from ..ext.tracking import initialize
             initialize(overwrite=True)
 
-        else:
+        elif args.action not in ['set','loc', 'show']:
             raise NotImplementedError("Try one of {show, set, loc}")
 
 
