@@ -1,4 +1,4 @@
-import gpustat as gp
+import gpustat as gp # TODO: add to requirements
 import time, os
 import subprocess as sp
 import sys
@@ -10,8 +10,11 @@ def monitor():
     return processes_per_gpu
 
 def submit(job_text):
-    # TODO: check correct env, but NOT part of the job_text
-    # TODO: don't submit again after run once.
+    '''
+    Submits a job and keeps it in Q until GPUs have no processes:
+
+    job_text:   e.g. `python train.py --lr 0.1`
+    '''
     tar_file = [ f for f in job_text.split(' ') if '.py' in f]
     torch = importlib.util.find_spec('torch') is not None
     assert len(tar_file)==1
