@@ -8,6 +8,54 @@ import cv2
 
 # np.set_printoptions(precision=3)
 
+# Return Jaccard index, or Intersection over Union (IoU) value
+def IoU(preds:Tensor, targs:Tensor, eps:float=1e-8):
+    """Computes the Jaccard loss, a.k.a the IoU loss.
+    Notes: [Batch size,Num classes,Height,Width]
+    Args:
+        targs: a tensor of shape [B, H, W] or [B, 1, H, W].
+        preds: a tensor of shape [B, C, H, W]. Corresponds to
+            the raw output or logits of the model. (prediction)
+        eps: added to the denominator for numerical stability.
+    Returns:
+        iou: the average class intersection over union value
+             for multi-class image segmentation
+    """
+    num_classes = preds.shape[1]
+
+    # Single class segmentation?
+    if num_classes == 1:
+        true_1_hot = torch.eye(num_classes + 1)[targs.squeeze(1)]
+        true_1_hot = true_1_hot.permute(0, 3, 1, 2).float()
+        true_1_hot_f = true_1_hot[:, 0:1, :, :]
+        true_1_hot_s = true_1_hot[:, 1:2, :, :]
+        true_1_hot = torch.cat([true_1_hot_s, true_1_hot_f], dim=1)
+        pos_prob = torch.sigmoid(preds)
+        neg_prob = 1 - pos_prob
+        probas = torch.cat([pos_prob, neg_prob], dim=1)
+
+    # Multi-class segmentation
+    else:
+        # Convert target to one-hot encoding
+        # true_1_hot = torch.eye(num_classes)[torch.squeeze(targs,1)]
+        true_1_hot = torch.eye(num_classes)[targs.squeeze(1)]
+
+        # Permute [B,H,W,C] to [B,C,H,W]
+        true_1_hot = true_1_hot.permute(0, 3, 1, 2).float()
+
+        # Take softmax along class dimension; all class probs add to 1 (per pixel)
+        probas = F.softmax(preds, dim=1)
+
+    true_1_hot = true_1_hot.type(preds.type())
+
+    # Sum probabilities by class and across batch images
+    dims = (0,) + tuple(range(2, targs.ndimension()))
+    intersection = torch.sum(probas * true_1_hot, dims) # [class0,class1,class2,...]
+    cardinality = torch.sum(probas + true_1_hot, dims)  # [class0,class1,class2,...]
+    union = cardinality - intersection
+    iou = (intersection / (union + eps)).mean()   # find mean of class IoU values
+    return iou
+
 def mean_iou(
         input: torch.Tensor,
         target: torch.Tensor,
@@ -83,9 +131,9 @@ def center_crop(path):
 
 def plot_result_comparison(standard_path,
                             learn: torch.nn.Module,
+                            label_fcn: Callable,
                             resize: tuple=None,
-                            crop_center: bool=False,
-                            label_fcn: Callable=None):
+                            crop_center: bool=False):
     '''
     Plots comparison of results using `learner` that is defined globally.
 
